#
# spec file for package cp210x-program
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2020-2023, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           cp210x-program
Version:        0.4.1
Release:        1.1
Summary:        EEPROM tool for Silabs CP210x USB-Serial adapters
License:        LGPL-2.1-only
Group:          Hardware/Other
URL:            http://cp210x-program.sourceforge.net/
#Git-Clone:     https://github.com/VCTLabs/cp210x-program.git
Source:         https://github.com/VCTLabs/cp210x-program/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-pytest
BuildRequires:  python3-pyusb
BuildRequires:  python3-setuptools
Requires:       python3-pyusb
BuildArch:      noarch

%description
The CP210x is an USB-to-serial chip used in a lot of USB devices (similar to
FTDIs and PL2303). The CP210x has a EEPROM on the chip which can be programmed
with this tool via USB.

%prep
%setup -q

%build
%python3_build

%install
%python3_install
%fdupes %{buildroot}/%{python3_sitelib}
mv %{buildroot}/%{_bindir}/cp210x-program.py %{buildroot}/%{_bindir}/cp210x-program

%files
%license LICENSE
%doc README.rst doc/cp210x.txt
%{_bindir}/cp210x-program
%{python3_sitelib}/cp210x*

%changelog
* Sun Aug 27 2023 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 0.4.1
  * Always write output files with newlines.
  * test binary mode for stdout stream.
  * Doc: initial readme updates and conversion to rst format.
  * FIX error: 'TypeError: can only concatenate str (not "bytes")
    to str'.
  * cp210x: Provide baud rate table as bytearray to pyusb
  * cp210x: Convert return of pyusb.ctrl_transfer to bytearray
  * fix format of sample ini files
    + get rid of duplicate line, which made ConfigParser throw an
    exception
    + get rid of leading spaces, which made ConfigParser interpret
    those entries as being additional lines in a multi-line value
    for 120000 entry
  * ini: Allow inline comments
* Mon Oct 26 2020 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 0.4
  * Port to Python3
  * Add basic tests
  * Fix -p option
  * docs: fix example of reading EEPROM
- Drop not longer used patches (included upstream)
  * 0001-docs-fix-example-of-reading-EEPROM.patch
  * https://github.com/VCTLabs/cp210x-program/pull/3.patch
* Sun Oct 25 2020 Martin Hauke <mardnh@gmx.de>
- Use updated patch for the python3 conversion
  * https://github.com/VCTLabs/cp210x-program/pull/3.patch
- Run testsuite
* Sat Oct 24 2020 Martin Hauke <mardnh@gmx.de>
- Initial package, version 0.3
- Add patches:
  * 0001-docs-fix-example-of-reading-EEPROM.patch
  * https://github.com/VCTLabs/cp210x-program/pull/2.patch
